/************************************************************************/
/*									*/
/*  A Symbol picker.							*/
/*									*/
/************************************************************************/

#   include	<appFrame.h>

typedef void (*SymbolPickerInsert)(	void *		target,
					int		symbol,
					int		fontFamilyNumber,
					char *		fontFamilyName,
					int		encoding,
					int		encodingIsDefault );

extern void * appMakeSymbolPicker(	APP_WIDGET		symbolOption,
					EditApplication *	ea,
					const char *		widgetName,
					APP_BITMAP_IMAGE	iconPixmap,
					APP_BITMAP_MASK		iconMask,
					SymbolPickerInsert	insert,
					AppToolDestroy		destroy,
					void *			target );

extern void appShowSymbolPicker(	void *	voidasp	);

extern int appAdaptSymbolPickerToFontFamily(	void *	voidasp,
						int	fontFamilyNumber,
						int	encoding );

extern void appEnableSymbolPicker(	void *	voidasp,
					int	enabled );
